Index: webrtc/p2p/base/candidate.h |
diff --git a/webrtc/p2p/base/candidate.h b/webrtc/p2p/base/candidate.h |
index ec758d2aa51c2659fdc15dd64cf60631fb566bf9..9a88b5f6d558adc850f889efb18a9a6d321ddf8b 100644 |
--- a/webrtc/p2p/base/candidate.h |
+++ b/webrtc/p2p/base/candidate.h |
@@ -27,8 +27,6 @@ |
namespace cricket { |
-const uint16_t kMaxNetworkCost = 999; |
- |
// Candidate for ICE based connection discovery. |
class Candidate { |
@@ -148,9 +146,9 @@ class Candidate { |
// |network_cost| measures the cost/penalty of using this candidate. A network |
// cost of 0 indicates this candidate can be used freely. A value of |
// |kMaxNetworkCost| indicates it should be used only as the last resort. |
void set_network_cost(uint16_t network_cost) { |
- ASSERT(network_cost <= kMaxNetworkCost); |
+ ASSERT(network_cost <= rtc::kMaxNetworkCost); |
network_cost_ = network_cost; |
} |
uint16_t network_cost() const { return network_cost_; } |
@@ -148,9 +146,9 @@ class Candidate { |
// |network_cost| measures the cost/penalty of using this candidate. A network |
// cost of 0 indicates this candidate can be used freely. A value of |
- // |kMaxNetworkCost| indicates it should be used only as the last resort. |
+ // rtc::kMaxNetworkCost indicates it should be used only as the last resort. |
void set_network_cost(uint16_t network_cost) { |